@@ -7,6 +7,8 @@ select <- c(TRUE, FALSE, FALSE, TRUE)
 ### http://www.nag.com/lapack-ex/node119.html
 select <- c(TRUE, FALSE, FALSE, TRUE)
 (ret <- qz(exAB2$A, exAB2$B, select = select))
+(ret <- ordqz(exAB2$A, exAB2$B, keyword = "ref"))
+(ret <- ordqz(exAB2$A, exAB2$B, keyword = "cef"))
 
 select <- c(TRUE, FALSE, FALSE, TRUE)
 (ret <- qz(exA1$A, select = select))
@@ -14,5 +16,8 @@ select <- c(TRUE, FALSE, FALSE, TRUE)
 ### http://www.nag.com/lapack-ex/node89.html
 select <- c(TRUE, FALSE, FALSE, TRUE)
 (ret <- qz(exA2$A, select = select))
-
+(ret <- ordqz(exA2$A, keyword = "lhp"))
+(ret <- ordqz(exA2$A, keyword = "rhp"))
+(ret <- ordqz(exA2$A, keyword = "ref"))
+(ret <- ordqz(exA2$A, keyword = "cef"))
 
